/*
 * @Company: hugeInfo
 * @Author: ldh
 * @Date: 2022-07-22 15:05:34
 * @LastEditTime: 2023-05-08 16:16:22
 * @LastEditors: lwh
 * @Version: 1.0.0
 * @Description: 调解档案
 */
import React, { useState, useEffect } from 'react';
import { Col, Row, Space, Image } from 'antd';
import { appUrl, ax, MyEmpty, dateFormat } from '../../../utils/utility';
import { archives } from '../../../assets/images/icon';

// 获取档案信息
function getDataApi(caseId) {
  return ax.request({ url: 'caseInfo/getCaseFilesInfo?caseId=' + caseId, type: 'get', service: 'mediate' });
}

const Archives = ({ caseId }) => {
  const [data, setData] = useState({});

  useEffect(() => {
    async function getData() {
      global.setSpinning(true);
      const res = await getDataApi(caseId);
      global.setSpinning(false);
      if (res.type) {
        setData(res.data || {});
      }
    }
    getData();
  }, [caseId]);

  return !data.fileTime ? (
    <div></div>
  ) : (
    <div className="mediationPower" style={{ position: 'relative' }}>
      <Row gutter={[16, 12]}>
        <Col span={24}>
          <Space size='small'>
            <div className='MediationInfo-subTitle'></div><h5> 档案信息</h5>
          </Space>
        </Col>
        {[
          { key: 'fileNo', label: '档案编号' },
          { key: 'fileYear', label: '年度' },
          { key: 'fileBookNo', label: '卷号' },
          { key: 'fileBookName', label: '卷名' },
          { key: 'fileUserName', label: '归档人' },
          { key: 'fileAddr', label: '档案存档位置' },
          { key: 'fileLimitYear', label: '保管年限' },
          { value: dateFormat(data.fileTime), label: '归档时间' },
          { key: 'fileContent', label: '卷宗情况说明' },
          {
            value: <Image width={100} src={appUrl.fileUrl + appUrl.fileShowUrl + (data.fileInfoList || [])[0]?.id} alt="" />,
            label: '归档封面',
          },
        ].map((x, t) => (
          <Col span={t === 0 ? 24 : 8} key={t}>
            <Space>
              <h5>{x.label}:</h5>
              <div>{x.value || data[x.key] || '-'}</div>
            </Space>
          </Col>
        ))}
      </Row>
      {/* <div style={{ position: 'absolute', right: 16, bottom: 16 }}>
        <img src={archives} alt="" />
      </div> */}
    </div>
  );
};

export default Archives;
